/*
  B E A   S Y S T E M S

  Copyright (c) 2005  BEA Systems, Inc.

  All Rights Reserved. Unpublished rights reserved under the copyright laws
  of the United States. The software contained on this media is proprietary
  to and embodies the confidential technology of BEA Systems, Inc. The
  possession or receipt of this information does not convey any right to disclose
  its contents, reproduce it, or use,  or license the use, for manufacture or
  sale, the information or anything described therein. Any use, disclosure, or
  reproduction without BEA System's prior written permission is strictly prohibited.

  This sample is for example purposes only and are not designed for production use.
  It serves as a companion to the WebLogic Portal Interaction Management Guide.

  This is a custom behavior tracking event. It uses the ResourceDisplayedEventBT.xsd
  schema to persist event attributes in the database as XML using the Behavior Tracking service.
  In addition, the custom event listener in these samples, customEventListener,
  listens for this event and persists the event attributes in custom database tables
  (not as XML).

  You can dispatch this event from a JSP, Java code, or a page flow and use it
  to trigger campaigns or capture it with a custom listener to perform custom
  functionality.

  This class requires APPLICATION\p13n_ejb.jar
 */

package examples.events;

import com.bea.p13n.tracking.events.TrackingEvent;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

/* Note: If you use events to trigger campaigns, you must have a string called "user-id"
 * that contains the user's profile name. You must also have a "request" attribute
 * of type com.bea.p13n.http.Request. The request attribute, however can be added
 * at runtime with: event.setAttribute("request", new Request(request, true));
*/

/* ResourceDisplayedEventBT */

public class ResourceDisplayedEventBT
    extends TrackingEvent
{
    /** Event Type */

    public static final String TYPE = "ResourceDisplayedEventBT";

    /**
     *  Event attribute key names for the defined event attributes.
     */

    public static final String RESOURCE_ID    = "resourceId";     // may be different than display label
    public static final String RESOURCE_LABEL = "resourceLabel";  // generally the display label
    public static final String RESOURCE_TYPE  = "resourceType";   // "page" or "portlet"
    public static final String SESSION_ID     = "session-id";     // needs to be this value for CaptureEvents.java
    public static final String USER_ID        = "user-id";        // needs to be this value for campaigns, and CaptureEvents.java
    public static final String SELECTED       = "resourceSelected";

     /** The following localschemaKeys array must be in the same order
      *  as they are listed in the XSD file.
     */

     private static final String localSchemaKeys[] =
     {
        RESOURCE_ID, RESOURCE_LABEL, RESOURCE_TYPE, SESSION_ID, USER_ID, SELECTED
     };

     private static final String XSD_FILE="ResourceDisplayedEventBT.xsd";
     private static final String XML_NAMESPACE="http://sample-events/xsd/tracking/resourcedisplayedeventbt";


    /** Constructor for ResourceDisplayedEventBT
     *
     * @param resourceId Resource Identifier
     * @param resourceLabel Resource Label
     * @param resourceType Resource Type
     * @param session_id Session ID
     * @param user_id User Name
     * @param timestamp Timestamp
     */

     public ResourceDisplayedEventBT (
         String resourceId,             // unique page/book ID
         String resourceLabel,          // visible name of page/book tab
         String resourceType,           // such as "page" or "portlet"
         String session_id,
         String user_id,
         String resourceSelected,       // variable for whether or not a page is selected - "true" or "false"
         HttpServletRequest request,
         HttpSession session )
     {
         super( TYPE,
                session,
                XML_NAMESPACE,
                XSD_FILE,
                localSchemaKeys,
                request
               );

        setAttribute( RESOURCE_ID,    resourceId );
        setAttribute( RESOURCE_LABEL, resourceLabel );
        setAttribute( RESOURCE_TYPE,  resourceType );
        setAttribute( SESSION_ID,     session_id );

        if( user_id != null )
             setAttribute( USER_ID, user_id );
        else
             setAttribute( USER_ID, "unknown" );

         setAttribute( SELECTED, resourceSelected );
     }

}   // end of ResourceDisplayedEventBT class
